/******************** (C) COPYRIGHT 2013 SONiX *******************************
* COMPANY:			SONiX
* DATE:					2013/12
* AUTHOR:				SA1
* IC:						SN32F760/750/740/730
* DESCRIPTION:	PFPA related functions.
*____________________________________________________________________________
* REVISION	Date				User		Description
* 1.0				2013/12/17	SA1			1. First release
*
*____________________________________________________________________________
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS TIME TO MARKET.
* SONiX SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL 
* DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH SOFTWARE
* AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN 
* IN CONNECTION WITH THEIR PRODUCTS.
*****************************************************************************/


/*_____ I N C L U D E S ____________________________________________________*/
#include <SN32F760.h>


/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
*/

/*--------------------- Clock Configuration ----------------------------------
//
//<e0> UART0
//		<o13.4..7> URXD0=
//					<0=> P0.0
//					<1=> P0.4
//					<2=> P1.3
//					<3=> P3.0
//					<4=> P3.3
//					<5=> P3.5
//					<6=> P3.11
//					<7=> P3.14
//		<o13.0..3> UTXD0=
//					<0=> P0.1
//					<1=> P0.5
//					<2=> P1.2
//					<3=> P3.1
//					<4=> P3.2
//					<5=> P3.4
//					<6=> P3.10
//					<7=> P3.15
//		<o13.16> URTS0=
//					<0=> Disable
//					<1=> P1.8
//		<o13.17> USCLK0=
//					<0=> Disable
//					<1=> P1.7
//		<o13.18> UCTS0=
//					<0=> Disable
//					<1=> P1.6
//</e>
//<e1> UART1
//		<o13.12..15> URXD1=
//					<0=> P1.0
//					<1=> P0.7
//					<2=> P0.12
//					<3=> P1.5
//					<4=> P1.13
//					<5=> P1.15
//					<6=> P3.6
//					<7=> P3.12
//		<o13.8..11> UTXD1=
//					<0=> P1.1
//					<1=> P0.6
//					<2=> P0.13
//					<3=> P1.4
//					<4=> P1.14
//					<5=> P3.8
//					<6=> P3.10
//					<7=> P3.13
//</e>
//<e2> SSP0
//		<o14.8..11> SCK0=
//					<0=> P0.4
//					<1=> P0.11
//					<2=> P0.13
//					<3=> P1.4
//					<4=> P1.12
//					<5=> P3.2
//					<6=> P3.6
//					<7=> P3.11
//					<8=> P2.3
//					<9=> P2.14
//		<o14.12..15> SEL0=
//					<0=> P0.5
//					<1=> P0.10
//					<2=> P0.12
//					<3=> P1.5
//					<4=> P1.11
//					<5=> P3.1
//					<6=> P3.5
//					<7=> P3.10
//					<8=> P2.0
//					<9=> P2.15
//		<o14.0..3> MISO0=
//					<0=> P0.2
//					<1=> P0.0
//					<2=> P0.6
//					<3=> P0.15
//					<4=> P1.0
//					<5=> P1.14
//					<6=> P3.3
//					<7=> P3.15
//					<8=> P2.1
//					<9=> P2.12
//		<o14.4..7> MOSI0=
//					<0=> P0.3
//					<1=> P0.1
//					<2=> P0.7
//					<3=> P0.14
//					<4=> P1.1
//					<5=> P1.15
//					<6=> P3.4
//					<7=> P3.14
//					<8=> P2.2
//					<9=> P2.13
//</e>
//<e3> SSP1
//		<o14.24..27> SCK1=
//					<0=> P3.7
//					<1=> P0.7
//					<2=> P0.14
//					<3=> P1.1
//					<4=> P1.11
//					<5=> P1.15
//					<6=> P3.3
//					<7=> P3.14
//					<8=> P2.2
//					<9=> P2.13
//		<o14.28..31> SEL1=
//					<0=> P3.6
//					<1=> P0.2
//					<2=> P0.13
//					<3=> P1.0
//					<4=> P1.4
//					<5=> P1.7
//					<6=> P1.14
//					<7=> P3.11
//					<8=> P2.1
//					<9=> P2.14
//		<o14.16..19> MISO1=
//					<0=> P3.9
//					<1=> P0.4
//					<2=> P0.10
//					<3=> P1.3
//					<4=> P1.10
//					<5=> P3.0
//					<6=> P3.4
//					<7=> P3.12
//					<8=> P2.1
//					<9=> P2.12
//		<o14.20..23> MOSI1=
//					<0=> P3.8
//					<1=> P0.5
//					<2=> P0.12
//					<3=> P1.2
//					<4=> P1.6
//					<5=> P1.13
//					<6=> P3.2
//					<7=> P3.13
//					<8=> P2.0
//					<9=> P2.15
//</e>
//<e4> I2C0
//		<o15.4..7> SCL0=
//					<0=> P1.5
//					<1=> P0.2
//					<2=> P0.15
//					<3=> P1.3
//					<4=> P1.14
//					<5=> P3.9
//					<6=> P3.11
//					<7=> P3.14
//		<o15.0..3> SDA0=
//					<0=> P1.4
//					<1=> P0.3
//					<2=> P0.10
//					<3=> P1.2
//					<4=> P1.13
//					<5=> P3.7
//					<6=> P3.13
//					<7=> P3.15
//</e>
//<e5> I2C1
//		<o15.12..15> SCL1=
//					<0=> P0.6
//					<1=> P0.0
//					<2=> P1.1
//					<3=> P1.9
//					<4=> P3.0
//					<5=> P3.3
//					<6=> P3.6
//					<7=> P3.13
//		<o15.8..11> SDA1=
//					<0=> P0.7
//					<1=> P0.1
//					<2=> P1.0
//					<3=> P1.8
//					<4=> P3.2
//					<5=> P3.4
//					<6=> P3.5
//					<7=> P3.12
//</e>
//<e6> I2S
//		<o16.0..3> MCLK=
//					<0=> P3.2
//					<1=> P0.12
//					<2=> P1.8
//					<3=> P3.7
//					<4=> P2.2
//					<5=> P2.6
//		<o16.4..7> BCLK=
//					<0=> P3.3
//					<1=> P0.13
//					<2=> P1.9
//					<3=> P3.6
//					<4=> P2.10
//					<5=> P2.11
//		<o16.8..11> WS=
//					<0=> P3.4
//					<1=> P0.14
//					<2=> P1.10
//					<3=> P2.1
//					<4=> P2.7
//					<5=> P2.9
//		<o16.12..15> DOUT=
//					<0=> P3.1
//					<1=> P0.11
//					<2=> P1.7
//					<3=> P3.8
//					<4=> P2.8
//					<5=> P2.12
//		<o16.16..19> DIN=
//					<0=> P3.0
//					<1=> P0.10
//					<2=> P1.6
//					<3=> P3.9
//					<4=> P2.0
//					<5=> P2.5
//</e>
//<e7> CT16B0
//		<o17.0..3> CAP0=
//					<0=> P0.2
//					<1=> P0.8
//					<2=> P1.0
//					<3=> P3.0
//					<4=> P3.2
//					<5=> P3.10
//					<6=> P2.0
//					<7=> P2.13
//		<o17.4..7> PWM0=
//					<0=> P0.0
//					<1=> P1.1
//					<2=> P1.8
//					<3=> P1.12
//					<4=> P3.3
//					<5=> P3.11
//					<6=> P2.3
//					<7=> P2.15
//		<o17.8..11> PWM1=
//					<0=> P0.1
//					<1=> P0.4
//					<2=> P0.10
//					<3=> P1.13
//					<4=> P3.4
//					<5=> P3.12
//					<6=> P2.2
//					<7=> P2.11
//		<o17.12..15> PWM2=
//					<0=> P1.12
//					<1=> P0.9
//					<2=> P0.11
//					<3=> P1.6
//					<4=> P3.6
//					<5=> P3.15
//					<6=> P2.4
//					<7=> P2.10
//</e>
//<e8> CT16B1
//		<o18.0..3> CAP0=
//					<0=> P0.12
//					<1=> P0.7
//					<2=> P1.7
//					<3=> P1.11
//					<4=> P3.5
//					<5=> P3.13
//					<6=> P2.1
//					<7=> P2.9
//		<o18.4..7> PWM0=
//					<0=> P0.10
//					<1=> P0.5
//					<2=> P1.9
//					<3=> P1.15
//					<4=> P3.7
//					<5=> P3.14
//					<6=> P2.0
//					<7=> P2.12
//		<o18.8..11> PWM1=
//					<0=> P0.11
//					<1=> P0.8
//					<2=> P0.12
//					<3=> P1.3
//					<4=> P1.10
//					<5=> P3.9
//					<6=> P2.4
//					<7=> P2.8
//		<o18.12..15> PWM2=
//					<0=> P1.9
//					<1=> P0.6
//					<2=> P0.15
//					<3=> P1.2
//					<4=> P1.14
//					<5=> P3.8
//					<6=> P2.3
//					<7=> P2.7
//</e>
//<e9> CT16B2
//		<o19.0..3> CAP0=
//					<0=> P1.8
//					<1=> P0.3
//					<2=> P0.13
//					<3=> P1.5
//					<4=> P3.6
//					<5=> P3.12
//					<6=> P2.2
//					<7=> P2.14
//		<o19.4..7> PWM0=
//					<0=> P3.5
//					<1=> P0.2
//					<2=> P0.14
//					<3=> P1.4
//					<4=> P3.1
//					<5=> P3.10
//					<6=> P2.5
//					<7=> P2.9
//		<o19.8..11> PWM1=
//					<0=> P1.4
//					<1=> P0.0
//					<2=> P0.9
//					<3=> P1.11
//					<4=> P3.5
//					<5=> P3.15
//					<6=> P2.1
//					<7=> P2.6
//		<o19.12..15> PWM2=
//					<0=> P3.1
//					<1=> P0.1
//					<2=> P1.0
//					<3=> P1.12
//					<4=> P3.0
//					<5=> P3.11
//					<6=> P2.4
//					<7=> P2.10
//</e>
//<e10> CT32B0
//		<o20.0..3> CAP0=
//					<0=> P3.9
//					<1=> P0.0
//					<2=> P0.9
//					<3=> P1.1
//					<4=> P3.1
//					<5=> P3.3
//					<6=> P2.3
//					<7=> P2.15
//		<o20.4..7> PWM0=
//					<0=> P1.15
//					<1=> P0.4
//					<2=> P0.11
//					<3=> P1.8
//					<4=> P1.14
//					<5=> P3.9
//					<6=> P2.3
//					<7=> P2.14
//		<o20.8..11> PWM1=
//					<0=> P3.8
//					<1=> P0.8
//					<2=> P0.14
//					<3=> P1.5
//					<4=> P1.11
//					<5=> P3.14
//					<6=> P2.4
//					<7=> P2.13
//		<o20.12..15> PWM2=
//					<0=> P1.14
//					<1=> P0.5
//					<2=> P0.9
//					<3=> P1.9
//					<4=> P3.7
//					<5=> P3.13
//					<6=> P2.0
//					<7=> P2.11
//		<o20.16..19> PWM3=
//					<0=> P1.2
//					<1=> P0.3
//					<2=> P0.7
//					<3=> P0.15
//					<4=> P1.12
//					<5=> P3.4
//					<6=> P2.2
//					<7=> P2.12
//</e>
//<e11> CT32B1
//		<o21.0..3> CAP0=
//					<0=> P1.3
//					<1=> P0.2
//					<2=> P0.8
//					<3=> P0.15
//					<4=> P1.6
//					<5=> P3.8
//					<6=> P2.4
//					<7=> P2.10
//		<o21.4..7> PWM0=
//					<0=> P1.13
//					<1=> P0.1
//					<2=> P0.9
//					<3=> P1.3
//					<4=> P3.2
//					<5=> P3.15
//					<6=> P2.6
//					<7=> P2.15
//		<o21.8..11> PWM1=
//					<0=> P0.15
//					<1=> P0.4
//					<2=> P1.2
//					<3=> P1.10
//					<4=> P3.5
//					<5=> P3.10
//					<6=> P2.1
//					<7=> P2.8
//		<o21.12..15> PWM2=
//					<0=> P1.6
//					<1=> P0.5
//					<2=> P0.8
//					<3=> P0.11
//					<4=> P3.12
//					<5=> P2.5
//					<6=> P2.12
//					<7=> P2.14
//		<o21.16..19> PWM3=
//					<0=> P1.7
//					<1=> P0.6
//					<2=> P0.7
//					<3=> P1.2
//					<4=> P3.9
//					<5=> P3.11
//					<6=> P2.4
//					<7=> P2.13
//</e>
//<e12> CT32B2
//		<o22.0..3> CAP0=
//					<0=> P3.7
//					<1=> P0.9
//					<2=> P0.10
//					<3=> P1.4
//					<4=> P1.13
//					<5=> P3.14
//					<6=> P2.5
//					<7=> P2.12
//		<o22.4..7> PWM0=
//					<0=> P0.13
//					<1=> P0.3
//					<2=> P0.8
//					<3=> P1.1
//					<4=> P1.7
//					<5=> P1.15
//					<6=> P2.11
//					<7=> P2.15
//		<o22.8..11> PWM1=
//					<0=> P0.14
//					<1=> P0.2
//					<2=> P0.15
//					<3=> P1.5
//					<4=> P3.0
//					<5=> P3.7
//					<6=> P2.7
//					<7=> P2.13
//		<o22.12..15> PWM2=
//					<0=> P0.3
//					<1=> P0.0
//					<2=> P0.9
//					<3=> P1.6
//					<4=> P3.1
//					<5=> P3.13
//					<6=> P3.15
//					<7=> P2.14
//		<o22.16..19> PWM3=
//					<0=> P0.6
//					<1=> P1.0
//					<2=> P1.7
//					<3=> P3.10
//					<4=> P2.3
//					<5=> P2.8
//					<6=> P2.9
//					<7=> P2.15
//</e>
//<o23.0>	MCU_TYPE=
//					<0=> SN32F760/750/740/730
//					<1=> SN32F240/230/220
*/
#define UART0_EN		0
#define UART1_EN		0
#define SSP0_EN			0
#define SSP1_EN			0
#define I2C0_EN			0
#define I2C1_EN			0
#define I2S_EN			0
#define CT16B0_EN		0
#define CT16B1_EN		0
#define CT16B2_EN		0
#define CT32B0_EN		0
#define CT32B1_EN		0
#define CT32B2_EN		0

#define PFPA_UART_VAL			0x00000077
#define PFPA_SSP_VAL			0x00000000
#define PFPA_I2C_VAL			0x00000000
#define PFPA_I2S_VAL			0x00000000
#define PFPA_CT16B0_VAL		0x00000000
#define PFPA_CT16B1_VAL		0x00000000
#define PFPA_CT16B2_VAL		0x00000000
#define PFPA_CT32B0_VAL		0x00000000
#define PFPA_CT32B1_VAL		0x00000000
#define PFPA_CT32B2_VAL		0x00000000

#define	USB_MCU						0x00000000
/*
//-------- <<< end of configuration section >>> ------------------------------
*/

/*_____ D E C L A R A T I O N S ____________________________________________*/
#if (USB_MCU == 0)
const uint32_t      BL_PFPA_UTXD0		__attribute__((at(0x000000e0))) = (PFPA_UART_VAL & 0xF);		//PFPA No of UTXD0 for Boot loader 
const uint32_t      BL_PFPA_URXD0		__attribute__((at(0x000000f0))) = (PFPA_UART_VAL>>4);				//PFPA No of URXD0 for Boot loader 
#endif


/*_____ F U N C T I O N S __________________________________________________*/
void PFPA_Init (void)
{
	SN_PFPA->UART = PFPA_UART_VAL;
	SN_PFPA->SSP = PFPA_SSP_VAL;
	SN_PFPA->I2C = PFPA_I2C_VAL;
	SN_PFPA->I2S = PFPA_I2S_VAL;
	SN_PFPA->CT16B0 = PFPA_CT16B0_VAL;
	SN_PFPA->CT16B1 = PFPA_CT16B1_VAL;
	SN_PFPA->CT16B2 = PFPA_CT16B2_VAL;
	SN_PFPA->CT32B0 = PFPA_CT32B0_VAL;
	SN_PFPA->CT32B1 = PFPA_CT32B1_VAL;
	SN_PFPA->CT32B2 = PFPA_CT32B2_VAL;
}
